==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/SummaryRowRootDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SummaryRowDescriptionMetadata } from "./SummaryRowDescriptionMetadata";
import { SummaryRowRootDescription } from "./SummaryRowRootDescription";
/**
 * @hidden
 */
var SummaryRowRootDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(SummaryRowRootDescriptionMetadata, _super);
    function SummaryRowRootDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    SummaryRowRootDescriptionMetadata.b = function (a) {
        if (SummaryRowRootDescriptionMetadata.a == null) {
            SummaryRowRootDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            SummaryRowRootDescriptionMetadata.c(SummaryRowRootDescriptionMetadata.a);
        }
        if (a.k(SummaryRowRootDescriptionMetadata.a)) {
            return;
        }
        a.aa(SummaryRowRootDescriptionMetadata.a);
    };
    SummaryRowRootDescriptionMetadata.c = function (a) {
        SummaryRowDescriptionMetadata.c(a);
    };
    SummaryRowRootDescriptionMetadata.d = function (a) {
        SummaryRowRootDescriptionMetadata.b(a);
        a.ac("SummaryRowRoot", function () { return new SummaryRowRootDescription(); });
        a.ab("SummaryRowRoot", SummaryRowRootDescriptionMetadata.a);
    };
    SummaryRowRootDescriptionMetadata.$t = markType(SummaryRowRootDescriptionMetadata, 'SummaryRowRootDescriptionMetadata');
    SummaryRowRootDescriptionMetadata.a = null;
    return SummaryRowRootDescriptionMetadata;
}(Base));
export { SummaryRowRootDescriptionMetadata };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/SummaryRowRootDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SummaryRowDescriptionMetadata } from "./SummaryRowDescriptionMetadata";
import { SummaryRowRootDescription } from "./SummaryRowRootDescription";
/**
 * @hidden
 */
var SummaryRowRootDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(SummaryRowRootDescriptionMetadata, _super);
    function SummaryRowRootDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    SummaryRowRootDescriptionMetadata.b = function (a) {
        if (SummaryRowRootDescriptionMetadata.a == null) {
            SummaryRowRootDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            SummaryRowRootDescriptionMetadata.c(SummaryRowRootDescriptionMetadata.a);
        }
        if (a.k(SummaryRowRootDescriptionMetadata.a)) {
            return;
        }
        a.ac(SummaryRowRootDescriptionMetadata.a);
    };
    SummaryRowRootDescriptionMetadata.c = function (a) {
        SummaryRowDescriptionMetadata.c(a);
    };
    SummaryRowRootDescriptionMetadata.d = function (a) {
        SummaryRowRootDescriptionMetadata.b(a);
        a.ae("SummaryRowRoot", function () { return new SummaryRowRootDescription(); });
        a.ad("SummaryRowRoot", SummaryRowRootDescriptionMetadata.a);
    };
    SummaryRowRootDescriptionMetadata.$t = markType(SummaryRowRootDescriptionMetadata, 'SummaryRowRootDescriptionMetadata');
    SummaryRowRootDescriptionMetadata.a = null;
    return SummaryRowRootDescriptionMetadata;
}(Base));
export { SummaryRowRootDescriptionMetadata };
